<?php

/**
 * @file
 * Admin functionality for Cookie content blocker.
 */

/**
 * Form callback for the admin settings form.
 *
 * @param array $form
 *   The structure of the form.
 * @param array $form_state
 *   The current state of the form.
 *
 * @return array
 *   The configuration form.
 *
 * @see system_settings_form_submit()
 */
function cookie_content_blocker_settings_form(array $form, array &$form_state) {
  module_load_include('inc', 'cookie_content_blocker', 'cookie_content_blocker.variable');
  $variable_info = cookie_content_blocker_variable_info(array());

  $type_map = array(
    'text' => 'textarea',
    'boolean' => 'checkbox',
    'string' => 'textfield',
  );

  foreach ($variable_info as $name => $info) {
    $current_value = variable_get($name, NULL);
    $form[$name] = array(
      '#type' => isset($type_map[$info['type']]) ? $type_map[$info['type']] : $info['type'],
      '#title' => $info['title'],
      '#description' => $info['description'],
      '#default_value' => $current_value === NULL ? $info['default'] : $current_value,
    );
  }

  $form['#after_build'] = array('cookie_content_blocker_settings_form_after_build');

  return system_settings_form($form);
}

/**
 * Form after build callback for the settings form.
 *
 * @param array $form_original
 *   The structure of the form.
 * @param array $form_state
 *   The current state of the form.
 *
 * @return array
 *   The configuration form.
 */
function cookie_content_blocker_settings_form_after_build(array $form_original, array &$form_state) {
  $form_shared['cookie_content_blocker_button_text'] = array(
    '#states' => array(
      'visible' => array(
        ':input[name="cookie_content_blocker_show_button"]' => array('checked' => TRUE),
      ),
    ),
  );
  $form_shared['cookie_content_blocker_enable_click_consent_change'] = array(
    '#states' => array(
      'visible' => array(
        ':input[name="cookie_content_blocker_show_button"]' => array('checked' => FALSE),
      ),
    ),
  );

  return array_merge_recursive($form_original, $form_shared);
}
